@@ -49,10 +49,15 @@ def addHeadingIds(doc, headings):
                 id = simplifyText(textContent(find(".content", header)))
                 header.set("id", safeID(doc, id))
     addOldIDs(headings)
-    if len(neededIds) > 0:
+    if len(neededIds) == 0:
+        pass
+    elif 1 <= len(neededIds) <= 5:
+        for el in neededIds:
+            warn(f"The heading '{textContent(el)}' needs a manually-specified ID.", el=el)
+    else:
         warn(
             "You should manually provide IDs for your headings:\n"
-            + "\n".join("  " + outerHTML(el) for el in neededIds),
+            + "\n".join("  " + textContent(el) for el in neededIds)
         )
 
 
@@ -65,8 +70,12 @@ def checkPrivacySecurityHeadings(headings):
             security = True
         if "privacy" in text and "considerations" in text:
             privacy = True
+        if "security" in text and "privacy" in text and "considerations" in text:
+            warn(
+                "W3C policy requires Privacy Considerations and Security Considerations to be separate sections, but you appear to have them combined into one.",
+                el=header,
+            )
         if security and privacy:
-            # No need to look any further!
             return
     if not security and not privacy:
         warn(
