@@ -12,7 +12,7 @@ def update(path, dryRun=False):
         sha = response.headers["x-wpt-sha"]
         jsonData = response.json()
     except Exception as e:
-        die("Couldn't download web-platform-tests data.\n{0}", e)
+        die(f"Couldn't download web-platform-tests data.\n{e}")
         return
 
     if "version" not in jsonData:
@@ -21,8 +21,7 @@ def update(path, dryRun=False):
 
     if jsonData["version"] != 8:
         die(
-            "Bikeshed currently only knows how to handle WPT v8 manifest data, but got v{0}. Please report this to the maintainer!",
-            jsonData["version"],
+            f"Bikeshed currently only knows how to handle WPT v8 manifest data, but got v{jsonData['version']}. Please report this to the maintainer!"
         )
         return
 
@@ -45,7 +44,7 @@ def update(path, dryRun=False):
                 for ordered_path in sorted(paths):
                     f.write(ordered_path + "\n")
         except Exception as e:
-            die("Couldn't save web-platform-tests data to disk.\n{0}", e)
+            die(f"Couldn't save web-platform-tests data to disk.\n{e}")
             return
     say("Success!")
 
