@@ -17,13 +17,14 @@ def processWptElements(doc):
     pathPrefix = doc.md.wptPathPrefix
 
     atLeastOneElement = False
+    atLeastOneVisibleTest = False
     testData = None
     # <wpt> elements
     wptElements = findAll("wpt", doc)
     seenTestNames = set()
     prevEl = None
     for el in wptElements:
-        if el.get("hidden") is None:
+        if atLeastOneElement is False and el.get("hidden") is None:
             atLeastOneElement = True
         if testData is None:
             testData = loadTestData(doc)
@@ -33,6 +34,8 @@ def processWptElements(doc):
                 die(f"Couldn't find WPT test '{testName}' - did you misspell something?", el=el)
                 continue
             seenTestNames.add(testName)
+            if atLeastOneVisibleTest is False and el.get("hidden") is None:
+                atLeastOneVisibleTest = True
         if el.get("hidden") is not None:
             removeNode(el)
         else:
@@ -60,11 +63,12 @@ def processWptElements(doc):
         if pathPrefix is None:
             die("Can't use <wpt-rest> without either a pathprefix=" " attribute or a 'WPT Path Prefix' metadata.")
             return
-        atLeastOneElement = True
         prefixedNames = [p for p in testData if prefixInPath(pathPrefix, p) and p not in seenTestNames]
         if len(prefixedNames) == 0:
             die(f"Couldn't find any tests with the path prefix '{pathPrefix}'.")
             return
+        atLeastOneElement = True
+        atLeastOneVisibleTest = True
         createHTML(doc, wptRestElements[0], prefixedNames, testData)
         warn(
             "<wpt-rest> is intended for debugging only. Move the tests to <wpt> elements next to what they're testing."
@@ -75,7 +79,7 @@ def processWptElements(doc):
                 testData = loadTestData(doc)
             checkForOmittedTests(pathPrefix, testData, seenTestNames)
 
-    if seenTestNames:
+    if atLeastOneVisibleTest:
         if pathPrefix is None:
             pathPrefix = commonPathPrefix(seenTestNames)
         if not pathPrefix.startswith("/"):
@@ -91,9 +95,12 @@ def processWptElements(doc):
                 )
             )
 
-    if atLeastOneElement and doc.md.wptDisplay != "none":
+    if doc.md.wptDisplay != "none" and atLeastOneElement:
+        # Empty <wpt> blocks still need styles
         doc.extraStyles["style-wpt"] = wptStyle
-        doc.extraScripts["script-wpt"] = getWptScript(pathPrefix)
+        if atLeastOneVisibleTest:
+            # But I only need script if there's actually some tests.
+            doc.extraScripts["script-wpt"] = getWptScript(pathPrefix)
 
 
 def createHTML(doc, blockEl, testNames, testData, title=None, titleLang=None, titleDir=None):
@@ -257,15 +264,10 @@ def checkForOmittedTests(pathPrefix, testData, seenTestNames):
                 unseenTests.append(testPath)
     if unseenTests:
         numTests = len(unseenTests)
-        if numTests < 10:
-            warn(
-                f"There are {numTests} WPT tests underneath your path prefix '{pathPrefix}' that aren't in your document and must be added:\n"
-                + "\n".join("  " + path for path in sorted(unseenTests)),
-            )
-        else:
-            warn(
-                f"There are {numTests} WPT tests (too many to display individually) underneath your path prefix '{pathPrefix}' that aren't in your document."
-            )
+        warn(
+            f"There are {numTests} WPT tests underneath your path prefix '{pathPrefix}' that aren't in your document and must be added. (Use a <wpt hidden> if you don't actually want them in your document.)\n"
+            + "\n".join("  " + path for path in sorted(unseenTests)),
+        )
 
 
 def loadTestData(doc):
